<?xml version="1.0" encoding="iso-8859-1"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">

<html xmlns="http://www.w3.org/1999/xhtml">

{% comment %}
<!--
  Copyright (C) 2015 University of Dundee & Open Microscopy Environment.
  All rights reserved.

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as
  published by the Free Software Foundation, either version 3 of the
  License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Affero General Public License for more details.

  You should have received a copy of the GNU Affero General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-->
{% endcomment %}

<head>

    <link rel="stylesheet" href="{% static "webclient/css/layout.css"|add:url_suffix %}" type="text/css" />

</head>
<body>

    <p>OMERO version {{ version }}</p>

    <p>This page has a wrong link to css that will raise HTTP 404</p>

    <p>Here is broken link to the image <img class="loader" alt="Loading" src="{% static "webclient/image/fake.gif" %}"></p>

    <p>Here is <a id="broken_link" href="{% url 'weberror404' %}1/">broken link 404</a></p>
    <p>Here is another <a id="broken_link" href="{% url 'weberror500' %}">broken link 500</a></p>
    <p>Here is <a id="broken_link" href="{% url 'weberrorwarn' %}">log warning</a></p>

</body>
</html>
